@@ -38,7 +38,7 @@ def get_packages(apt_cache=None):
     return packages
 
 
-def get_software_context(apt_cache=None, lsb_information=None):
+def get_software_context(apt_cache=None, lsb_information=None, test=None):
     """ Return dict used for storing software_context information
 
     test_id - Unique identifier for this test
@@ -50,6 +50,10 @@ def get_software_context(apt_cache=None, lsb_information=None):
     software_context = {}
     software_context['image'] = get_image(lsb_information)
     software_context['packages'] = get_packages(apt_cache)
+    if test and test.installer:
+        sources = test.installer.get_software_sources(test.install_dir)
+        if sources:
+            software_context['sources'] = sources
     return software_context
 
 
@@ -69,3 +73,4 @@ def get_image(lsb_information=None):
             lsb_information = lsb_release.get_distro_information()
         name = lsb_information['DESCRIPTION']
     return {"name": name}
+
