@@ -23,7 +23,6 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
-INSTALLSTEPS = ['']
 DEPS = ['gatortests']
 
 RUNSTEPS = ["gatortests"]
@@ -31,7 +30,7 @@ DEFAULT_OPTIONS = ""
 
 PATTERN = "^\*\*\*(?P<test_case_id>\w+):\s(?P<result>\w+)\*\*\*"
 
-installer = TestInstaller(INSTALLSTEPS, deps=DEPS)
+installer = TestInstaller(deps=DEPS)
 runner = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
 parser = TestParser(pattern=PATTERN)
 
